null_broadcast

Function null_broadcast 

pub(super) fn null_broadcast<E: Clock + Spawner + Metrics + BufferPooler>(
    context: E,
    mailbox_size: usize,
) -> Mailbox<PublicKey, Block>
Create a null broadcast mailbox

In follow mode, there are no consensus peers to broadcast state or request information from. The FollowResolver is backed by the execution node and upstream ws connection.